Crate cith

Crate cith 

Structs

City32Hasher
A std::hash::Hasher implementation using the 32-bit variant of CityHash.
City64Hasher
A Hasher implementation based on the 64-bit variant of CityHash.
Hash256

Functions

city_hash32
Computes the 32-bit CityHash of a byte slice.
city_hash64
Computes the 64-bit CityHash of a byte slice.
city_hash64_with_seed
Computes a 64-bit CityHash value for the given byte slice, using the specified seed.
city_hash128
Computes a 128-bit CityHash value for the given byte slice.
city_hash128_crc
Computes a 128-bit CRC-based CityHash of the given byte slice.
city_hash128_crc_with_seed
Computes a 128-bit CRC-based CityHash of the given byte slice with a seed.
city_hash128_with_seed
Computes the 128-bit CityHash value of the given byte slice using the provided 128-bit seed.
city_hash256_crc
Computes a 256-bit CRC-based CityHash of the given byte slice.
city_hash256_crc_with_seed
Computes a 256-bit CityHash CRC hash of the given byte slice with a custom seed.
city_murmur
Computes the 128-bit CityMurmur hash of a byte slice.
city_murmur_with_seed
Computes the 128-bit CityMurmur hash of a byte slice using a custom seed.