Structs
- City32
Hasher - A
std::hash::Hasherimplementation using the 32-bit variant of CityHash. - City64
Hasher - A
Hasherimplementation based on the 64-bit variant of CityHash. - Hash256
Functions
- city_
hash32 - Computes the 32-bit CityHash of a byte slice.
- city_
hash64 - Computes the 64-bit CityHash of a byte slice.
- city_
hash64_ with_ seed - Computes a 64-bit CityHash value for the given byte slice, using the specified seed.
- city_
hash128 - Computes a 128-bit CityHash value for the given byte slice.
- city_
hash128_ crc - Computes a 128-bit CRC-based CityHash of the given byte slice.
- city_
hash128_ crc_ with_ seed - Computes a 128-bit CRC-based CityHash of the given byte slice with a seed.
- city_
hash128_ with_ seed - Computes the 128-bit CityHash value of the given byte slice using the provided 128-bit seed.
- city_
hash256_ crc - Computes a 256-bit CRC-based CityHash of the given byte slice.
- city_
hash256_ crc_ with_ seed - Computes a 256-bit CityHash CRC hash of the given byte slice with a custom seed.
- city_
murmur - Computes the 128-bit CityMurmur hash of a byte slice.
- city_
murmur_ with_ seed - Computes the 128-bit CityMurmur hash of a byte slice using a custom seed.